{% extends "appbuilder/baselayout.html" %}

{% block head_css %}
{{super()}}
<link rel="shortcut icon" href="{{ url_for('static', filename='chaudron.png') }}">
<style>
.navbar-brand a {
  color: white;
}
.navbar {
    -webkit-box-shadow: 0px 3px 3px #AAA;
    -moz-box-shadow:    0px 3px 3px #AAA;
    box-shadow:         0px 3px 3px #AAA;
    z-index:999;
}
.panel.panel-primary {
  margin: 10px;
}
</style>
{% endblock %}
