{% extends "appbuilder/base.html" %}
{% block content %}
<div class="container">
  <div class="jumbotron">
      <h1>Panoramix</h1>
      <p>Panoramix is an interactive visualization platform built on top of Druid.io</p>
    </div>
  <div class="text-center">
  <img width="250" src="/static/tux_panoramix.png">
  </div>
</div>
{% endblock %}

